@@ -20,6 +20,7 @@
 #include <QDateTime>
 #include <QLocale>
 #include <QDebug>
+#include <QRegExp>
 
 #include <KLocalizedString>
 
@@ -28,8 +29,20 @@
 #include "documentman.h"
 #include "kraftdb.h"
 #include "defaultprovider.h"
+#include "kraftsettings.h"
+#include "format.h"
 
-const char *SentOutDateC = "SentOutDate";
+namespace {
+
+QString multilineHtml( const QString& str )
+{
+    QString re {str.toHtmlEscaped()};
+
+    re.replace( '\n', "<br/>");
+    return re;
+}
+
+} // end namespace
 
 ArchDoc::ArchDoc()
     : mAttributes( QLatin1String("ArchDoc"))
@@ -56,6 +69,33 @@ QString ArchDoc::docIdentifier() const
   return i18n("%1 for %2 (Id %3)", re, ident() );
 }
 
+QString ArchDoc::dateStr() const
+{
+    return Format::toDateString(mDate, KraftSettings::self()->dateFormat());
+}
+
+
+QString ArchDoc::preText() const
+{
+    return mPreText;
+}
+
+QString ArchDoc::preTextHtml() const
+{
+    return multilineHtml(mPreText);
+}
+
+QString ArchDoc::postText() const
+{
+    return mPostText;
+}
+
+QString ArchDoc::postTextHtml() const
+{
+    return multilineHtml(mPostText);
+}
+
+
 Geld ArchDoc::nettoSum() const
 {
     const Geld g = positions().sumPrice();
@@ -72,18 +112,39 @@ Geld ArchDoc::bruttoSum() const
 
 Geld ArchDoc::taxSum() const
 {
-    const Geld g = positions().taxSum( tax(), reducedTax() );
+    const Geld g = positions().taxSum();
     return  g;
 }
 
 Geld ArchDoc::fullTaxSum() const
 {
-    return positions().fullTaxSum( tax() );
+    return positions().fullTaxSum();
 }
 
 Geld ArchDoc::reducedTaxSum() const
 {
-    return positions().reducedTaxSum( reducedTax() );
+    return positions().reducedTaxSum();
+}
+
+QString ArchDoc::fullTaxPercentStr() const
+{
+   return Format::localeDoubleToString(mTax, *DefaultProvider::self()->locale());
+}
+
+QString ArchDoc::reducedTaxPercentStr() const
+{
+   return Format::localeDoubleToString(mReducedTax, *DefaultProvider::self()->locale());
+}
+
+QString ArchDoc::taxPercentStr() const
+{
+     DocPositionBase::TaxType tt = mPositions.listTaxation();
+     if (tt == DocPositionBase::TaxType::TaxFull) {
+         return fullTaxPercentStr();
+     } else if (tt == DocPositionBase::TaxType::TaxReduced) {
+         return reducedTaxSumStr();
+     }
+     return QString();
 }
 
 double ArchDoc::tax() const
@@ -157,6 +218,8 @@ void ArchDoc::loadItems( const QString& archDocId )
       qDebug() << "Error: " << q.lastError().nativeErrorCode();
   }
 
+  mPositions.setTaxes(mTax, mReducedTax);
+
   while( q.next() ) {
     ArchDocPosition pos;
     pos.mPosNo = q.value( 2 ).toString();
@@ -179,6 +242,11 @@ void ArchDoc::loadItems( const QString& archDocId )
   }
 }
 
+QList<ArchDocPosition> ArchDoc::itemslist() const
+{
+    return mPositions;
+}
+
 QDateTime ArchDoc::sentOutDate()
 {
     QDateTime re;
@@ -229,10 +297,6 @@ ArchDocDigest::~ArchDocDigest()
 
 }
 
-QString ArchDocDigest::printDateString() const
-{
-    return DefaultProvider::self()->locale()->toString( mPrintDate, QLocale::ShortFormat);
-}
 
 /* ###################################################################### */
 
