@@ -90,6 +90,21 @@ QString ArchDocPosition::taxMarkerHelper() const
     return re;
 }
 
+QString ArchDocPosition::htmlText(const QString& paraStyle) const
+{
+    QString re;
+
+    QString style( paraStyle );
+    if ( style.isEmpty() ) style = QStringLiteral("text");
+
+    // Keep empty parts allows multiple newlines here
+    const QStringList li = mText.toHtmlEscaped().split( "\n", Qt::KeepEmptyParts );
+
+    re = li.join("<br/>");
+
+    return re;
+}
+
 // ==================================================================
 
 ArchDocPositionList::ArchDocPositionList()
