@@ -31,6 +31,7 @@
 #include "kraftsettings.h"
 #include "documentman.h"
 #include "defaultprovider.h"
+#include "format.h"
 
 Q_GLOBAL_STATIC(ArchiveMan, mSelf)
 
@@ -107,8 +108,7 @@ QDomDocument ArchiveMan::archiveDocumentXml( KraftDoc *doc, const QString& archI
   docElem.appendChild( xmlTextElement( xmldoc, "salut", doc->salut() ) );
   docElem.appendChild( xmlTextElement( xmldoc, "goodbye", doc->goodbye() ) );
 
-  docElem.appendChild( xmlTextElement( xmldoc, "date",
-                                       DefaultProvider::self()->locale()->toString( doc->date() ) ));
+  docElem.appendChild( xmlTextElement( xmldoc, "date", Format::toDateString(doc->date(), Format::DateFormatIso)));
 
   root.appendChild( doc->positions().domElement( xmldoc ) );
 
@@ -268,15 +268,19 @@ void ArchiveMan::ensureDirIsExisting( const QString& dir ) const
 
 QString ArchiveMan::xmlBaseDir() const
 {
-  QString outputDir = KraftSettings::self()->pdfOutputDir();
-  if ( outputDir.isEmpty() ) {
-    outputDir = QStandardPaths::writableLocation( QStandardPaths::AppDataLocation );
-  }
+    QString outputDir = KraftSettings::self()->xmlArchivePath();
+    if ( outputDir.isEmpty() ) {
+        // stay bug compatible: Before issue #80, this was the pdfOutputDir
+        outputDir = KraftSettings::self()->pdfOutputDir();
+    }
+    if (outputDir.isEmpty()) {
+        outputDir = QStandardPaths::writableLocation( QStandardPaths::AppDataLocation );
+    }
 
-  if ( ! outputDir.endsWith( "/" ) ) outputDir += "/";
-  ensureDirIsExisting(outputDir);
+    if ( ! outputDir.endsWith('/') ) outputDir += QChar('/');
+    ensureDirIsExisting(outputDir);
 
-  return outputDir;
+    return outputDir;
 }
 
 QString ArchiveMan::pdfBaseDir() const
@@ -286,7 +290,7 @@ QString ArchiveMan::pdfBaseDir() const
     outputDir = QStandardPaths::writableLocation( QStandardPaths::AppDataLocation );
   }
 
-  if ( ! outputDir.endsWith( "/" ) ) outputDir += "/";
+  if ( ! outputDir.endsWith('/') ) outputDir += QChar('/');
   ensureDirIsExisting(outputDir);
 
   return outputDir;
