@@ -47,14 +47,17 @@ public:
   DocTextList documentTexts( const QString&, KraftDoc::Part );
 
   QString currencySymbol() const;
+
   QLocale* locale();
 
   QString iconvTool() const;
+  QStringList findTrml2Pdf() const;
+  QString locateKraftTool(const QString& toolName) const;
+  QString locateBinary(const QString& name) const;
+  QString locateFile(const QString& findFile) const;
 
   QString getStyleSheet( const QString& ) const;
 
-  QString locateFile(const QString& findFile) const;
-
   DefaultProvider();
 
 private:
