@@ -57,6 +57,7 @@
 #include "templtopositiondialogbase.h"
 #include "doctype.h"
 #include "catalogtemplate.h"
+#include "format.h"
 
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -94,11 +95,11 @@ KraftViewRO::~KraftViewRO()
 
 }
 
-#define QL1(X) QLatin1String(X)
+#define QL1(X) QStringLiteral(X)
 
 QString KraftViewRO::htmlify( const QString& str ) const
 {
-  QStringList li = Qt::escape(str).split( "\n" );
+  QStringList li = str.toHtmlEscaped().split( "\n" );
   return QL1("<p>") + li.join( "</p><p>" ) + QL1("</p>");
 }
 
@@ -110,7 +111,7 @@ void KraftViewRO::setup( DocGuardedPtr doc )
 
     if ( !doc ) return;
 
-    QLocale *locale = doc->locale();
+    QLocale *locale = DefaultProvider::self()->locale();
 
     // do stuff like open a template and render values into it.
     QString tmplFile = DefaultProvider::self()->locateFile( "views/kraftdoc_ro.thtml" );
@@ -123,12 +124,13 @@ void KraftViewRO::setup( DocGuardedPtr doc )
     }
 
 
-    TextTemplate tmpl( tmplFile );
-    if( !tmpl.open() ) {
+    TextTemplate tmpl;
+    tmpl.setTemplateFileName(tmplFile);
+    if( !tmpl.isOk() ) {
         return;
     }
     tmpl.setValue( DOC_RO_TAG( "HEADLINE" ), doc->docType() + " " + doc->ident() );
-    tmpl.setValue( DOC_RO_TAG( "DATE" ), doc->date().toString());
+    tmpl.setValue( DOC_RO_TAG( "DATE" ), Format::toDateString(doc->date(), KraftSettings::self()->dateFormat()));
     tmpl.setValue( DOC_RO_TAG( "DOC_TYPE" ),  doc->docType() );
     QString address = doc->address();
     address.replace( '\n', "<br/>" );
@@ -232,7 +234,7 @@ void KraftViewRO::setup( DocGuardedPtr doc )
         if ( positions.reducedTaxSum( redTax ).toLong() > 0 ) {
             tmpl.createSubDictionary( "DISPLAY_SUM_BLOCK", "SECTION_REDUCED_TAX"  );
             tmpl.setValue( "SECTION_REDUCED_TAX", DOC_RO_TAG( "REDUCED_TAX_SUM" ),
-                           positions.reducedTaxSum( redTax ).toString( positions.locale() ) );
+                           positions.reducedTaxSum( redTax ).toString() );
             h.setNum( redTax, 'f', 1 );
             tmpl.setValue( "SECTION_REDUCED_TAX", DOC_RO_TAG( "REDUCED_TAX" ), h );
             tmpl.setValue( "SECTION_REDUCED_TAX", DOC_RO_TAG( "REDUCED_TAX_LABEL" ), i18n( "reduced VAT" ) );
@@ -241,7 +243,7 @@ void KraftViewRO::setup( DocGuardedPtr doc )
         if ( positions.fullTaxSum( fullTax ).toLong() > 0 ) {
             tmpl.createSubDictionary( "DISPLAY_SUM_BLOCK", "SECTION_FULL_TAX" );
             tmpl.setValue( "SECTION_FULL_TAX", DOC_RO_TAG( "FULL_TAX_SUM" ),
-                           positions.fullTaxSum( fullTax ).toString( positions.locale() ) );
+                           positions.fullTaxSum( fullTax ).toString() );
             h.setNum( fullTax, 'f', 1 );
             tmpl.setValue( "SECTION_FULL_TAX", DOC_RO_TAG( "FULL_TAX" ), h );
             tmpl.setValue( "SECTION_FULL_TAX", DOC_RO_TAG( "FULL_TAX_LABEL" ), i18n( "VAT" ) );
@@ -253,13 +255,12 @@ void KraftViewRO::setup( DocGuardedPtr doc )
     setWindowTitle( m_doc->docIdentifier() );
 
     mHtmlView->setTitle( doc->docIdentifier() );
-    const QString content = tmpl.expand();
-    mHtmlView->displayContent( content );
+    mHtmlView->displayContent(tmpl.expand());
 }
 
 void KraftViewRO::slotLinkClicked(const QString& link)
 {
-    Q_UNUSED(link);
+    Q_UNUSED(link)
     // nothing we do here yet
 }
 
