@@ -18,7 +18,7 @@
 #include <QBitmap>
 #include <QImage>
 #include <QPalette>
-
+#include <QMetaType>
 #include <QDebug>
 #include <QApplication>
 #include <QCommandLineParser>
@@ -32,12 +32,15 @@
 #include "version.h"
 #include "portal.h"
 #include "defaultprovider.h"
+#include "archdocposition.h"
 
 int main(int argc, char *argv[])
 {
     KLocalizedString::setApplicationDomain("kraft");
     Q_INIT_RESOURCE(kraft);
 
+    qRegisterMetaType<ArchDocPositionList>("ArchDocPositionList");
+
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon(":/kraft/global/32-apps-kraft.png"));
     app.setApplicationName("kraft");
@@ -52,31 +55,8 @@ int main(int argc, char *argv[])
 
     // Register the supported options
     QScopedPointer<Portal> kraftPortal;
-    if (app.isSessionRestored()) {
-        // FIXME: Add session management
-        // RESTORE(Portal);
-    } else {
-        QString splashFile = DefaultProvider::self()->locateFile("pics/kraftsplash.png" );
-        QSplashScreen *splash = nullptr;
-
-        if( !splashFile.isEmpty()) {
-            QPixmap pixmap( splashFile );
-
-            splash = new QSplashScreen( pixmap, Qt::WindowStaysOnTopHint );
-            splash->setMask(pixmap.mask());
-            splash->show();
-        }
-
-        kraftPortal.reset( new Portal( nullptr, &parser, "kraft main window" ));
-        kraftPortal->show();
-
-        if( splash ) {
-            splash->finish( kraftPortal.data() );
-            splash->deleteLater();
-        } else {
-            // qDebug () << "Could not find splash screen";
-        }
-    }
+    kraftPortal.reset( new Portal( nullptr, &parser, "kraft main window" ));
+    kraftPortal->show();
 
     return app.exec();
 }
