@@ -335,15 +335,15 @@ QWidget* PrefsDialog::docTab()
   const QDate d = QDate::currentDate();
   mCbDateFormats->setToolTip( i18n( "The default date format for documents." ) );
   QString formattedDate = d.toString(Qt::ISODate);
-  mCbDateFormats->insertItem( 0, i18n("ISO-Format: %1").arg(formattedDate));
+  mCbDateFormats->insertItem( 0, i18n("ISO-Format: %1", formattedDate));
   formattedDate = d.toString(Qt::DefaultLocaleShortDate);
-  mCbDateFormats->insertItem( 1, i18n("Short-Date: %1").arg(formattedDate));
+  mCbDateFormats->insertItem( 1, i18n("Short-Date: %1", formattedDate));
   formattedDate = d.toString(Qt::DefaultLocaleLongDate);
-  mCbDateFormats->insertItem( 2, i18n("Long-Date: %1").arg(formattedDate));
+  mCbDateFormats->insertItem( 2, i18n("Long-Date: %1", formattedDate));
   formattedDate = d.toString(Qt::RFC2822Date);
-  mCbDateFormats->insertItem( 3, i18n("RFC 2822-Format: %1").arg(formattedDate));
+  mCbDateFormats->insertItem( 3, i18n("RFC 2822-Format: %1", formattedDate));
   formattedDate = d.toString("dd.MM.yyyy");
-  mCbDateFormats->insertItem( 4, i18n("\"German Format\": %1").arg(formattedDate));
+  mCbDateFormats->insertItem( 4, i18n("\"German Format\": %1", formattedDate));
   mCbDateFormats->insertItem( 5, i18n("Custom Setting in Settingsfile"));
   vboxLay->addLayout( butLay );
 
@@ -545,7 +545,7 @@ void PrefsDialog::accept()
 }
 
 #define IDENTITY_TAG(X) QLatin1String(X)
-#define QL1(X) QLatin1String(X)
+#define QL1(X) QStringLiteral(X)
 
 void PrefsDialog::fillManualIdentityForm(const KContacts::Addressee& addressee)
 {
@@ -581,6 +581,14 @@ void PrefsDialog::setMyIdentity( const KContacts::Addressee& addressee, bool bac
 
   QString addressBookInfo;
   _pbChangeIdentity->setEnabled(backendUp);
+
+  QPalette p;
+  QColor c = p.color(QPalette::Normal, QPalette::ToolTipBase);
+  tmpl.setValue(IDENTITY_TAG("CSS_WARN_BACKGROUND_COLOR"), c.name());
+
+  c =  p.color(QPalette::Normal, QPalette::QPalette::Base);
+  tmpl.setValue(IDENTITY_TAG("CSS_IDENTITY_IMAGE_BACKGROUND"), "#ea4e1d"); // c.name());
+
   if( !backendUp ) {
       addressBookInfo = i18n("The identity can not be found.");
       tmpl.createDictionary(QL1("NO_IDENTITY"));
@@ -668,7 +676,8 @@ void PrefsDialog::setMyIdentity( const KContacts::Addressee& addressee, bool bac
       }
   }
 
-  mIdentityView->displayContent(tmpl.expand());
+  const QString ex = tmpl.expand();
+  mIdentityView->displayContent(ex);
 }
 
 TaxItemDelegate::TaxItemDelegate(QObject * parent) : QItemDelegate(parent) {}
