@@ -27,6 +27,9 @@
 #include "unitmanager.h"
 #include "materialsaverbase.h"
 #include "materialsaverdb.h"
+#include "defaultprovider.h"
+#include "format.h"
+#include "kraftsettings.h"
 
 StockMaterial::StockMaterial( ):
     CatalogTemplate(),
@@ -150,19 +153,12 @@ void StockMaterial::setEnterDate( QDate dt )
 
 QString StockMaterial::lastModified()
 {
-  return dateShortFormat( mLastModified );
+  return Format::toDateString( mLastModified, KraftSettings::self()->dateFormat());
 }
 
 QString StockMaterial::entered()
 {
-  return dateShortFormat( mEnteredDate );
-}
-
-
-QString StockMaterial::dateShortFormat( QDate d )
-{
-  // return d.toString();
-  return QString( "%1/%2" ).arg( d.month() ).arg( d.year() );
+  return Format::toDateString( mEnteredDate, KraftSettings::self()->dateFormat() );
 }
 
 void StockMaterial::saveChapterId()
